@@ -6,20 +6,21 @@ with support for multiple programming languages, input/output validation, and
 security protection against destructive operations.
 """
 
-from .core.executor import execute
+from .core.executor import execute, get_ready
 from .core.docker_manager import rm_docker
 from .exceptions import CoexError, SecurityError, ExecutionError, DockerError
 
-__version__ = "0.1.4"
+__version__ = "0.1.6"
 __author__ = "torchtorchkimtorch"
 __email__ = "torchtorchkimtorch@users.noreply.github.com"
 
 # Main API exports
 __all__ = [
     "execute",
+    "get_ready",
     "rm_docker",
     "CoexError",
-    "SecurityError", 
+    "SecurityError",
     "ExecutionError",
     "DockerError",
 ]
