@@ -9,7 +9,8 @@ import ast
 import traceback
 from typing import List, Optional, Union, Any, Dict, Tuple
 from .docker_manager import get_docker_manager
-from .subprocess_executor import get_subprocess_executor, cleanup_subprocess_executor
+from .docker_subprocess_executor import get_docker_subprocess_executor, cleanup_docker_subprocess_executor
+from .lazy_installer import get_lazy_installer, cleanup_lazy_installer
 from .languages import language_manager
 from .security import validate_code, sanitize_code
 from ..config.settings import settings
@@ -29,7 +30,7 @@ class CodeExecutor:
     def __init__(self):
         """Initialize the code executor."""
         self.docker_manager = get_docker_manager()
-        self.subprocess_executor = get_subprocess_executor()
+        self.docker_subprocess_executor = get_docker_subprocess_executor()
     
     def execute(self,
                 inputs: Optional[List[Any]] = None,
@@ -69,12 +70,12 @@ class CodeExecutor:
             execution_mode = self._determine_execution_mode(inputs, outputs, code, answer_fn, mode)
 
             if execution_mode == "answer":
-                return self._execute_input_output_mode_subprocess(inputs, outputs, code, language, timeout)
+                return self._execute_input_output_mode_docker(inputs, outputs, code, language, timeout)
             elif execution_mode == "function":
-                return self._execute_function_comparison_mode_subprocess(answer_fn, code, language, timeout)
+                return self._execute_function_comparison_mode_docker(answer_fn, code, language, timeout)
             else:
                 # Simple execution mode
-                return self._execute_simple_mode_subprocess(code, language, timeout)
+                return self._execute_simple_mode_docker(code, language, timeout)
 
         except SecurityError as e:
             # Return all failures for security violations
@@ -398,18 +399,18 @@ except Exception as e:
             # Fallback to string comparison
             return str(actual).strip() == str(expected).strip()
 
-    def _execute_input_output_mode_subprocess(self, inputs: List[Any], outputs: List[Any],
-                                            code: str, language: str,
-                                            timeout: Optional[int]) -> List[int]:
-        """Execute code with input/output validation using subprocess."""
+    def _execute_input_output_mode_docker(self, inputs: List[Any], outputs: List[Any],
+                                         code: str, language: str,
+                                         timeout: Optional[int]) -> List[int]:
+        """Execute code with input/output validation using Docker subprocess."""
         results = []
 
-        print(f"[INFO] Executing {len(inputs)} test cases using host system {language}")
+        print(f"[INFO] Executing {len(inputs)} test cases using Docker {language}")
 
         for i, (input_val, expected_output) in enumerate(zip(inputs, outputs)):
             try:
-                # Execute code with input using subprocess
-                actual_output = self.subprocess_executor.execute_code(
+                # Execute code with input using Docker subprocess
+                actual_output = self.docker_subprocess_executor.execute_code(
                     code, language, input_val, timeout
                 )
 
@@ -427,28 +428,28 @@ except Exception as e:
 
         return results
 
-    def _execute_function_comparison_mode_subprocess(self, answer_fn: str, code: str,
-                                                   language: str, timeout: Optional[int]) -> List[int]:
-        """Execute function comparison mode using subprocess."""
+    def _execute_function_comparison_mode_docker(self, answer_fn: str, code: str,
+                                               language: str, timeout: Optional[int]) -> List[int]:
+        """Execute function comparison mode using Docker subprocess."""
         try:
-            print(f"[INFO] Executing function comparison using host system {language}")
+            print(f"[INFO] Executing function comparison using Docker {language}")
 
             # For now, just execute the code and return success if no error
-            self.subprocess_executor.execute_code(code, language, None, timeout)
+            self.docker_subprocess_executor.execute_code(code, language, None, timeout)
             return [1]
 
         except Exception as e:
             logger.error(f"Function comparison failed: {e}")
             return [0]
 
-    def _execute_simple_mode_subprocess(self, code: str, language: str,
-                                      timeout: Optional[int]) -> List[int]:
-        """Execute simple mode using subprocess."""
+    def _execute_simple_mode_docker(self, code: str, language: str,
+                                  timeout: Optional[int]) -> List[int]:
+        """Execute simple mode using Docker subprocess."""
         try:
-            print(f"[INFO] Executing code using host system {language}")
+            print(f"[INFO] Executing code using Docker {language}")
 
             # Execute code without input
-            self.subprocess_executor.execute_code(code, language, None, timeout)
+            self.docker_subprocess_executor.execute_code(code, language, None, timeout)
             return [1]
 
         except Exception as e:
@@ -513,10 +514,31 @@ def rm_docker() -> None:
         docker_manager = get_docker_manager()
         docker_manager.cleanup_all_containers()
 
-        # Also cleanup subprocess executor
-        cleanup_subprocess_executor()
+        # Also cleanup Docker subprocess executor and lazy installer
+        cleanup_docker_subprocess_executor()
+        cleanup_lazy_installer()
 
         logger.info("All Docker containers and subprocess resources cleaned up")
     except Exception as e:
         logger.error(f"Failed to cleanup resources: {e}")
         raise
+
+
+def get_ready(*languages: str) -> None:
+    """
+    Pre-install language packages in the Docker container.
+
+    Args:
+        *languages: Variable number of language names to pre-install
+
+    Example:
+        get_ready("java", "javascript")  # Pre-install Java and JavaScript
+        get_ready("python", "cpp", "go")  # Pre-install multiple languages
+    """
+    try:
+        lazy_installer = get_lazy_installer()
+        lazy_installer.pre_install_languages(list(languages))
+        logger.info(f"Pre-installed languages: {', '.join(languages)}")
+    except Exception as e:
+        logger.error(f"Failed to pre-install languages: {e}")
+        raise
